@@ -67,6 +67,7 @@ __all__ = (
     "FirehoseTypeDef",
     "GetBootstrapBrokersResponseTypeDef",
     "GetCompatibleKafkaVersionsResponseTypeDef",
+    "IamTypeDef",
     "JmxExporterInfoTypeDef",
     "JmxExporterTypeDef",
     "KafkaVersionTypeDef",
@@ -325,12 +326,17 @@ class GetBootstrapBrokersResponseTypeDef(TypedDict, total=False):
     BootstrapBrokerString: str
     BootstrapBrokerStringTls: str
     BootstrapBrokerStringSaslScram: str
+    BootstrapBrokerStringSaslIam: str
 
 
 class GetCompatibleKafkaVersionsResponseTypeDef(TypedDict, total=False):
     CompatibleKafkaVersions: List["CompatibleKafkaVersionTypeDef"]
 
 
+class IamTypeDef(TypedDict, total=False):
+    Enabled: bool
+
+
 class JmxExporterInfoTypeDef(TypedDict):
     EnabledInBroker: bool
 
@@ -455,6 +461,7 @@ class S3TypeDef(_RequiredS3TypeDef, total=False):
 
 class SaslTypeDef(TypedDict, total=False):
     Scram: "ScramTypeDef"
+    Iam: "IamTypeDef"
 
 
 class ScramTypeDef(TypedDict, total=False):
